.. highlight:: rst

Acknowledgement
===============


Development of CLIMLAB and associated documentation is partially supported
by the National Science Foundation under Grant Number AGS-1455071 to Brian Rose.

Any opinions, findings, and conclusions or recommendations expressed in this
material are those of the author(s) and do not necessarily reflect the views of
the National Science Foundation.
